"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const helper_1 = require("./helper");
const typescript_ilogger_1 = require("typescript-ilogger");
const test_values_1 = require("./test-values");
const stream_1 = require("stream");
const readable = new stream_1.Readable();
const completeMultipartUploadOutputResponse = {};
const copyObjectOutputResponse = {};
const createBucketOutputResponse = {};
const createMultipartUploadOutputResponse = {};
const deleteBucketOutputResponse = {};
const deleteObjectOutputResponse = {};
const deleteObjectsOutputResponse = {};
const deleteObjectTaggingOutputResponse = {};
const getObjectOutputResponse = { Body: readable };
const getObjectTaggingOutputResponse = {
    TagSet: [{ Key: 'Tag1', Value: 'Tag1Value' }],
};
const headBucketOutputResponse = {};
const headObjectOutputResponse = {
    Metadata: { key1: 'value1' },
};
const putObjectOutputResponse = {};
const putObjectTaggingOutputResponse = {};
const uploadPartOutputResponse = {};
const completeMultipartUpload = jest.fn().mockImplementation(() => {
    return Promise.resolve(completeMultipartUploadOutputResponse);
});
const copyObject = jest.fn().mockImplementation(() => {
    return Promise.resolve(copyObjectOutputResponse);
});
const createBucket = jest.fn().mockImplementation(() => {
    return Promise.resolve(createBucketOutputResponse);
});
const createMultipartUpload = jest.fn().mockImplementation(() => {
    return Promise.resolve(createMultipartUploadOutputResponse);
});
const deleteBucket = jest.fn().mockImplementation(() => {
    return Promise.resolve(deleteBucketOutputResponse);
});
const deleteObject = jest.fn().mockImplementation(() => {
    return Promise.resolve(deleteObjectOutputResponse);
});
const deleteObjects = jest.fn().mockImplementation(() => {
    return Promise.resolve(deleteObjectsOutputResponse);
});
const deleteObjectTagging = jest.fn().mockImplementation(() => {
    return Promise.resolve(deleteObjectTaggingOutputResponse);
});
const getObject = jest.fn().mockImplementation(() => {
    return Promise.resolve(getObjectOutputResponse);
});
const getObjectTagging = jest.fn().mockImplementation(() => {
    return Promise.resolve(getObjectTaggingOutputResponse);
});
const headBucket = jest.fn().mockImplementation(() => {
    return Promise.resolve(headBucketOutputResponse);
});
const headObject = jest.fn().mockImplementation(() => {
    return Promise.resolve(headObjectOutputResponse);
});
const putObject = jest.fn().mockImplementation(() => {
    return Promise.resolve(putObjectOutputResponse);
});
const putObjectTagging = jest.fn().mockImplementation(() => {
    return Promise.resolve(putObjectTaggingOutputResponse);
});
const uploadPart = jest.fn().mockImplementation(() => {
    return Promise.resolve(uploadPartOutputResponse);
});
jest.mock('@aws-sdk/client-s3', () => {
    return {
        S3: jest.fn().mockImplementation(() => {
            return {
                completeMultipartUpload,
                copyObject,
                createBucket,
                createMultipartUpload,
                deleteBucket,
                deleteObject,
                deleteObjects,
                deleteObjectTagging,
                getObject,
                getObjectTagging,
                headBucket,
                headObject,
                putObject,
                putObjectTagging,
                uploadPart,
            };
        }),
    };
});
const logger = new typescript_ilogger_1.Logger(typescript_ilogger_1.LogLevel.Off);
const s3HelperMock = new helper_1.S3Helper(logger);
const TestValues = new test_values_1.TestingValues();
describe(`${helper_1.S3Helper.name}.${s3HelperMock.CopyObjectAsync.name}`, () => {
    const action = `${helper_1.S3Helper.name}.${s3HelperMock.CopyObjectAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} sourceBucket`, () => {
        const actual = s3HelperMock.CopyObjectAsync(TestValues.EmptyString, TestValues.Key, TestValues.Name, TestValues.Key);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} sourceBucket`);
    });
    test(`${TestValues.ThrowsOnEmpty} sourceKey`, () => {
        const actual = s3HelperMock.CopyObjectAsync(TestValues.Name, TestValues.EmptyString, TestValues.Name, TestValues.Key);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} sourceKey`);
    });
    test(`${TestValues.ThrowsOnEmpty} destinationBucket`, () => {
        const actual = s3HelperMock.CopyObjectAsync(TestValues.Name, TestValues.Key, TestValues.EmptyString, TestValues.Key);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} destinationBucket`);
    });
    test(`${TestValues.ThrowsOnEmpty} destinationKey`, () => {
        const actual = s3HelperMock.CopyObjectAsync(TestValues.Name, TestValues.Key, TestValues.Name, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} destinationKey`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = s3HelperMock.CopyObjectAsync(TestValues.Name, TestValues.Key, TestValues.Name, TestValues.Key);
        return expect(actual).resolves.toEqual(copyObjectOutputResponse);
    });
});
describe(`${helper_1.S3Helper.name}.${s3HelperMock.CreateBucketAsync.name}`, () => {
    const action = `${helper_1.S3Helper.name}.${s3HelperMock.CreateBucketAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} bucket`, () => {
        const actual = s3HelperMock.CreateBucketAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} name`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = s3HelperMock.CreateBucketAsync(TestValues.Name);
        return expect(actual).resolves.toEqual(createBucketOutputResponse);
    });
});
describe(`${helper_1.S3Helper.name}.${s3HelperMock.DeleteBucketAsync.name}`, () => {
    const action = `${helper_1.S3Helper.name}.${s3HelperMock.DeleteBucketAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} bucket`, () => {
        const actual = s3HelperMock.DeleteBucketAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} name`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = s3HelperMock.DeleteBucketAsync(TestValues.Name);
        return expect(actual).resolves.toEqual(createBucketOutputResponse);
    });
});
describe(`${helper_1.S3Helper.name}.${s3HelperMock.DeleteObjectTagsAsync.name}`, () => {
    const action = `${helper_1.S3Helper.name}.${s3HelperMock.DeleteObjectTagsAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} bucket`, () => {
        const actual = s3HelperMock.DeleteObjectTagsAsync(TestValues.EmptyString, TestValues.Name);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} bucket`);
    });
    test(`${TestValues.ThrowsOnEmpty} key`, () => {
        const actual = s3HelperMock.DeleteObjectTagsAsync(TestValues.Name, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} key`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = s3HelperMock.DeleteObjectTagsAsync(TestValues.Name, TestValues.Name);
        return expect(actual).resolves.toEqual({});
    });
});
describe(`${helper_1.S3Helper.name}.${s3HelperMock.DeleteObjectAsync.name}`, () => {
    const action = `${helper_1.S3Helper.name}.${s3HelperMock.DeleteObjectAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} bucket`, () => {
        const actual = s3HelperMock.DeleteObjectAsync(TestValues.EmptyString, TestValues.Key);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} bucket`);
    });
    test(`${TestValues.ThrowsOnEmpty} key`, () => {
        const actual = s3HelperMock.DeleteObjectAsync(TestValues.Name, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} key`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = s3HelperMock.DeleteObjectAsync(TestValues.Name, TestValues.Key);
        return expect(actual).resolves.toEqual(createBucketOutputResponse);
    });
});
describe(`${helper_1.S3Helper.name}.${s3HelperMock.DeleteObjectsAsync.name}`, () => {
    const action = `${helper_1.S3Helper.name}.${s3HelperMock.DeleteObjectsAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} bucket`, () => {
        const actual = s3HelperMock.DeleteObjectsAsync(TestValues.EmptyString, [
            TestValues.Key,
        ]);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} bucket`);
    });
    test(`${TestValues.ThrowsOnEmpty} key array`, () => {
        const actual = s3HelperMock.DeleteObjectsAsync(TestValues.Name, TestValues.EmptyArray);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} at least one key`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = s3HelperMock.DeleteObjectsAsync(TestValues.Name, [
            TestValues.Key,
        ]);
        return expect(actual).resolves.toEqual(createBucketOutputResponse);
    });
});
describe(`${helper_1.S3Helper.name}.${s3HelperMock.GetBucketMetadataAsync.name}`, () => {
    const action = `${helper_1.S3Helper.name}.${s3HelperMock.GetBucketMetadataAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} bucket`, () => {
        const actual = s3HelperMock.GetBucketMetadataAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} bucket`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = s3HelperMock.GetBucketMetadataAsync(TestValues.Name);
        return expect(actual).resolves.toEqual(createBucketOutputResponse);
    });
});
describe(`${helper_1.S3Helper.name}.${s3HelperMock.GetObjectAsJsonAsync.name}`, () => {
    const action = `${helper_1.S3Helper.name}.${s3HelperMock.GetObjectAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} bucket`, () => {
        const actual = s3HelperMock.GetObjectAsJsonAsync(TestValues.EmptyString, TestValues.Key);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} bucket`);
    });
    test(`${TestValues.ThrowsOnEmpty} key`, () => {
        const actual = s3HelperMock.GetObjectAsJsonAsync(TestValues.Name, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} key`);
    });
});
describe(`${helper_1.S3Helper.name}.${s3HelperMock.GetObjectAsync.name}`, () => {
    const action = `${helper_1.S3Helper.name}.${s3HelperMock.GetObjectAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} bucket`, () => {
        const actual = s3HelperMock.GetObjectAsync(TestValues.EmptyString, TestValues.Key);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} bucket`);
    });
    test(`${TestValues.ThrowsOnEmpty} key`, () => {
        const actual = s3HelperMock.GetObjectAsync(TestValues.Name, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} key`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = s3HelperMock.GetObjectAsync(TestValues.Name, TestValues.Key);
        return expect(actual).resolves.toEqual(getObjectOutputResponse);
    });
});
describe(`${helper_1.S3Helper.name}.${s3HelperMock.GetObjectContentsAsync.name}`, () => {
    const action = `${helper_1.S3Helper.name}.${s3HelperMock.GetObjectAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} bucket`, () => {
        const actual = s3HelperMock.GetObjectContentsAsync(TestValues.EmptyString, TestValues.Key);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} bucket`);
    });
    test(`${TestValues.ThrowsOnEmpty} key`, () => {
        const actual = s3HelperMock.GetObjectContentsAsync(TestValues.Name, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} key`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = s3HelperMock.GetObjectContentsAsync(TestValues.Name, TestValues.Key);
        return expect(actual).resolves.toEqual(getObjectOutputResponse.Body);
    });
});
describe(`${helper_1.S3Helper.name}.${s3HelperMock.GetObjectMetadataAsync.name}`, () => {
    const action = `${helper_1.S3Helper.name}.${s3HelperMock.GetObjectMetadataAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} bucket`, () => {
        const actual = s3HelperMock.GetObjectMetadataAsync(TestValues.EmptyString, TestValues.Name);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} bucket`);
    });
    test(`${TestValues.ThrowsOnEmpty} key`, () => {
        const actual = s3HelperMock.GetObjectMetadataAsync(TestValues.Name, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} key`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = s3HelperMock.GetObjectMetadataAsync(TestValues.Name, TestValues.Key);
        return expect(actual).resolves.toEqual(TestValues.Metadata);
    });
});
describe(`${helper_1.S3Helper.name}.${s3HelperMock.GetObjectTagsAsync.name}`, () => {
    const action = `${helper_1.S3Helper.name}.${s3HelperMock.GetObjectTagsAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} bucket`, () => {
        const actual = s3HelperMock.GetObjectTagsAsync(TestValues.EmptyString, TestValues.Key);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} bucket`);
    });
    test(`${TestValues.ThrowsOnEmpty} key`, () => {
        const actual = s3HelperMock.GetObjectTagsAsync(TestValues.Name, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} key`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = s3HelperMock.GetObjectTagsAsync(TestValues.Name, TestValues.Key);
        return expect(actual).resolves.toEqual(TestValues.FileTags);
    });
});
describe(`${helper_1.S3Helper.name}.${s3HelperMock.MoveObjectAsync.name}`, () => {
    const action = `${helper_1.S3Helper.name}.${s3HelperMock.CopyObjectAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} sourceBucket`, () => {
        const actual = s3HelperMock.MoveObjectAsync(TestValues.EmptyString, TestValues.Key, TestValues.Name, TestValues.Key);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} sourceBucket`);
    });
    test(`${TestValues.ThrowsOnEmpty} sourceKey`, () => {
        const actual = s3HelperMock.MoveObjectAsync(TestValues.Name, TestValues.EmptyString, TestValues.Name, TestValues.Key);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} sourceKey`);
    });
    test(`${TestValues.ThrowsOnEmpty} destinationBucket`, () => {
        const actual = s3HelperMock.MoveObjectAsync(TestValues.Name, TestValues.Key, TestValues.EmptyString, TestValues.Key);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} destinationBucket`);
    });
    test(`${TestValues.ThrowsOnEmpty} destinationKey`, () => {
        const actual = s3HelperMock.MoveObjectAsync(TestValues.Name, TestValues.Key, TestValues.Name, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} destinationKey`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = s3HelperMock.MoveObjectAsync(TestValues.Name, TestValues.Key, TestValues.Name, TestValues.Key);
        return expect(actual).resolves.toEqual(undefined);
    });
});
describe(`${helper_1.S3Helper.name}.${s3HelperMock.MultipartUploadCompleteAsync.name}`, () => {
    const action = `${helper_1.S3Helper.name}.${s3HelperMock.MultipartUploadCompleteAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} bucket`, () => {
        const actual = s3HelperMock.MultipartUploadCompleteAsync(TestValues.EmptyString, TestValues.Key, TestValues.UploadId);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} bucket`);
    });
    test(`${TestValues.ThrowsOnEmpty} key`, () => {
        const actual = s3HelperMock.MultipartUploadCompleteAsync(TestValues.Name, TestValues.EmptyString, TestValues.UploadId);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} key`);
    });
    test(`${TestValues.ThrowsOnEmpty} uploadId`, () => {
        const actual = s3HelperMock.MultipartUploadCompleteAsync(TestValues.Name, TestValues.Key, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} uploadId`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = s3HelperMock.MultipartUploadCompleteAsync(TestValues.Name, TestValues.Key, TestValues.UploadId);
        return expect(actual).resolves.toEqual(completeMultipartUploadOutputResponse);
    });
});
describe(`${helper_1.S3Helper.name}.${s3HelperMock.MultipartUploadStartAsync.name}`, () => {
    const action = `${helper_1.S3Helper.name}.${s3HelperMock.MultipartUploadStartAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} bucket`, () => {
        const actual = s3HelperMock.MultipartUploadStartAsync(TestValues.EmptyString, TestValues.Key);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} bucket`);
    });
    test(`${TestValues.ThrowsOnEmpty} key`, () => {
        const actual = s3HelperMock.MultipartUploadStartAsync(TestValues.Name, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} key`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = s3HelperMock.MultipartUploadStartAsync(TestValues.Name, TestValues.Key);
        return expect(actual).resolves.toEqual(createMultipartUploadOutputResponse);
    });
});
describe(`${helper_1.S3Helper.name}.${s3HelperMock.MultipartUploadUploadPartAsync.name}`, () => {
    const action = `${helper_1.S3Helper.name}.${s3HelperMock.MultipartUploadUploadPartAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} bucket`, () => {
        const actual = s3HelperMock.MultipartUploadUploadPartAsync(TestValues.EmptyString, TestValues.Key, TestValues.UploadId, TestValues.UploadPart, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} bucket`);
    });
    test(`${TestValues.ThrowsOnEmpty} key`, () => {
        const actual = s3HelperMock.MultipartUploadUploadPartAsync(TestValues.Name, TestValues.EmptyString, TestValues.UploadId, TestValues.UploadPart, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} key`);
    });
    test(`${TestValues.ThrowsOnEmpty} uploadId`, () => {
        const actual = s3HelperMock.MultipartUploadUploadPartAsync(TestValues.Name, TestValues.Key, TestValues.EmptyString, TestValues.UploadPart, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} uploadId`);
    });
    test(`${TestValues.CannotBeZero} uploadId`, () => {
        const actual = s3HelperMock.MultipartUploadUploadPartAsync(TestValues.Name, TestValues.Key, TestValues.UploadId, 0, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.CannotBeZero} - uploadId`);
    });
    test(`${TestValues.ThrowsOnEmpty} contents`, () => {
        const actual = s3HelperMock.MultipartUploadUploadPartAsync(TestValues.Name, TestValues.Key, TestValues.UploadId, TestValues.UploadPart, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} contents`);
    });
    test(`contents too small`, () => {
        const actual = s3HelperMock.MultipartUploadUploadPartAsync(TestValues.Name, TestValues.Key, TestValues.UploadId, TestValues.UploadPart, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-Part size must be between 5 MB and 10 GB`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = s3HelperMock.MultipartUploadUploadPartAsync(TestValues.Name, TestValues.Key, TestValues.UploadId, TestValues.UploadPart, TestValues.UploadPart5Mb);
        return expect(actual).resolves.toEqual(uploadPartOutputResponse);
    });
});
describe(`${helper_1.S3Helper.name}.${s3HelperMock.PutObjectAsync.name}`, () => {
    const action = `${helper_1.S3Helper.name}.${s3HelperMock.PutObjectAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} bucket`, () => {
        const actual = s3HelperMock.PutObjectAsync(TestValues.EmptyString, TestValues.Key, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} bucket`);
    });
    test(`${TestValues.ThrowsOnEmpty} key`, () => {
        const actual = s3HelperMock.PutObjectAsync(TestValues.Name, TestValues.EmptyString, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} key`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = s3HelperMock.PutObjectAsync(TestValues.Name, TestValues.Key, TestValues.Body);
        return expect(actual).resolves.toEqual(putObjectOutputResponse);
    });
});
describe(`${helper_1.S3Helper.name}.${s3HelperMock.SetObjectTagAsync.name}`, () => {
    const action = `${helper_1.S3Helper.name}.${s3HelperMock.SetObjectTagAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} bucket`, () => {
        const actual = s3HelperMock.SetObjectTagAsync(TestValues.EmptyString, TestValues.Key, TestValues.Name, TestValues.Name);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} bucket`);
    });
    test(`${TestValues.ThrowsOnEmpty} key`, () => {
        const actual = s3HelperMock.SetObjectTagAsync(TestValues.Name, TestValues.EmptyString, TestValues.Name, TestValues.Name);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} key`);
    });
    test(`${TestValues.ThrowsOnEmpty} tagName`, () => {
        const actual = s3HelperMock.SetObjectTagAsync(TestValues.Name, TestValues.Key, TestValues.EmptyString, TestValues.Name);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} tagName`);
    });
    test(`${TestValues.ThrowsOnEmpty} tagValue`, () => {
        const actual = s3HelperMock.SetObjectTagAsync(TestValues.Name, TestValues.Key, TestValues.Name, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} tagValue`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = s3HelperMock.SetObjectTagAsync(TestValues.Name, TestValues.Key, TestValues.Name, TestValues.Name);
        return expect(actual).resolves.toEqual(putObjectOutputResponse);
    });
});
describe(`${helper_1.S3Helper.name}.${s3HelperMock.SetObjectTagsAsync.name}`, () => {
    const action = `${helper_1.S3Helper.name}.${s3HelperMock.SetObjectTagsAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} bucket`, () => {
        const actual = s3HelperMock.SetObjectTagsAsync(TestValues.EmptyString, TestValues.Key, TestValues.FileTags);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} bucket`);
    });
    test(`${TestValues.ThrowsOnEmpty} key`, () => {
        const actual = s3HelperMock.SetObjectTagsAsync(TestValues.Name, TestValues.EmptyString, TestValues.FileTags);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} key`);
    });
    test(`${TestValues.ThrowsOnEmpty} tags`, () => {
        const actual = s3HelperMock.SetObjectTagsAsync(TestValues.Name, TestValues.Key, TestValues.EmptyArray);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} tags`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = s3HelperMock.SetObjectTagsAsync(TestValues.Name, TestValues.Key, TestValues.FileTags);
        return expect(actual).resolves.toEqual(putObjectOutputResponse);
    });
});
//# sourceMappingURL=helper-resolves.spec.js.map